"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.withHTML = void 0;

var _addons = require("@storybook/addons");

var _constants = require("./constants");

var withHTML = (0, _addons.makeDecorator)({
  name: "withHTML",
  parameterName: "html",
  skipIfNoParametersOrOptions: false,
  wrapper: function wrapper(storyFn, context, _ref) {
    var _ref$parameters = _ref.parameters,
        parameters = _ref$parameters === void 0 ? {} : _ref$parameters;
    var emit = (0, _addons.useChannel)({});
    setTimeout(function () {
      var rootSelector = parameters.root || "#root";
      var root = document.querySelector(rootSelector);
      var code = root ? root.innerHTML : "".concat(rootSelector, " not found.");
      var removeEmptyComments = parameters.removeEmptyComments,
          removeComments = parameters.removeComments,
          customReplacement = parameters.customReplacement;

      if (removeEmptyComments) {
        code = code.replace(/<!--\s*-->/g, "");
      }

      if (removeComments === true) {
        code = code.replace(/<!--[\S\s]*?-->/g, "");
      } else if (removeComments instanceof RegExp) {
        code = code.replace(/<!--([\S\s]*?)-->/g, function (match, p1) {
          return removeComments.test(p1) ? "" : match;
        });
      }

      code = customSearchAndReplace(code, customReplacement);
      emit(_constants.EVENTS.CODE_UPDATE, {
        code: code,
        options: parameters
      });
    }, 0);
    return storyFn(context);
  }
});
exports.withHTML = withHTML;

var customSearchAndReplace = function customSearchAndReplace(code, customReplacement) {
  if (!customReplacement) {
    return code;
  }

  var getSearchReplaceObject = function getSearchReplaceObject(input) {
    if (input instanceof RegExp) {
      return {
        search: input,
        replace: ""
      };
    } else if (input instanceof Object) {
      var search = input.search,
          replace = input.replace;
      return {
        search: search && (search instanceof RegExp || typeof search === "string") ? search : false,
        replace: replace && typeof replace === "string" ? replace : ""
      };
    }
  };

  var customReplacementList = customReplacement || [];

  if (!Array.isArray(customReplacementList)) {
    customReplacementList = [customReplacement];
  }

  customReplacementList.map(function (v) {
    return getSearchReplaceObject(v);
  }).filter(function (v) {
    return v.search;
  }).forEach(function (v) {
    code = code.replace(v.search, v.replace);
  });
  return code;
};

if (module && module.hot && module.hot.decline) {
  module.hot.decline();
}